@@ -13,8 +13,8 @@ func (s *Suite) Test_NewMkAssignChecker(c *check.C) {
 	ck.check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:1: VAR is defined but not used.",
-		"WARN: filename.mk:1: OTHER is used but not defined.")
+		"WARN: filename.mk:1: Variable \"VAR\" is defined but not used.",
+		"WARN: filename.mk:1: Variable \"OTHER\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkAssignChecker_check(c *check.C) {
@@ -29,7 +29,28 @@ func (s *Suite) Test_MkAssignChecker_check(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: Makefile:2: ac_cv_libpari_libs is defined but not used.")
+		"WARN: Makefile:2: Variable \"ac_cv_libpari_libs\" is defined but not used.")
+}
+
+func (s *Suite) Test_MkAssignChecker_check__outside_pkgsrc(c *check.C) {
+	t := s.Init(c)
+	G.Project = NewNetBSDProject()
+	G.Pkgsrc = nil
+	t.CreateFileLines("filename.mk",
+		MkCvsID,
+		"_CPPFLAGS.${t:Z}+=\t${FIX_RPATH}")
+
+	G.Check(t.File("filename.mk"))
+
+	t.CheckOutputLines(
+		// No warning about _CPPFLAGS being infrastructure-only.
+		"WARN: ~/filename.mk:2: Invalid variable modifier \"Z\" for \"t\".",
+		// XXX: This may be overzealous outside pkgsrc,
+		// XXX: without knowing any further context.
+		"WARN: ~/filename.mk:2: Variable \"t\" is used but not defined.",
+		// No warning about FIX_RPATH being deprecated.
+		"WARN: ~/filename.mk:2: Variable \"FIX_RPATH\" is used but not defined.",
+	)
 }
 
 // Pkglint once interpreted all lists as consisting of shell tokens,
@@ -117,8 +138,8 @@ func (s *Suite) Test_MkAssignChecker_checkLeft__infrastructure(c *check.C) {
 	G.Check(t.File("wip/mk/infra.mk"))
 
 	t.CheckOutputLines(
-		"WARN: ~/mk/infra.mk:2: _VARNAME is defined but not used.",
-		"WARN: ~/wip/mk/infra.mk:2: _CVS_ENV is defined but not used.")
+		"WARN: ~/mk/infra.mk:2: Variable \"_VARNAME\" is defined but not used.",
+		"WARN: ~/wip/mk/infra.mk:2: Variable \"_CVS_ENV\" is defined but not used.")
 }
 
 func (s *Suite) Test_MkAssignChecker_checkLeft__documented_underscore(c *check.C) {
@@ -158,7 +179,7 @@ func (s *Suite) Test_MkAssignChecker_checkLeftNotUsed__procedure_call(c *check.C
 	// This has the added benefit that the parameter is only evaluated
 	// once, especially if it contains references to other variables.
 	t.CheckOutputLines(
-		"WARN: ~/category/package/filename.mk:6: VAR is defined but not used.")
+		"WARN: ~/category/package/filename.mk:6: Variable \"VAR\" is defined but not used.")
 }
 
 func (s *Suite) Test_MkAssignChecker_checkLeftNotUsed__procedure_call_no_tracing(c *check.C) {
@@ -201,8 +222,8 @@ func (s *Suite) Test_MkAssignChecker_checkLeftNotUsed__infra(c *check.C) {
 	G.Check(t.File("category/package"))
 
 	t.CheckOutputLines(
-		"WARN: ~/category/package/Makefile:22: UNUSED_INFRA is defined but not used.",
-		"WARN: ~/category/package/Makefile:22: UNDOCUMENTED is used but not defined.")
+		"WARN: ~/category/package/Makefile:22: Variable \"UNUSED_INFRA\" is defined but not used.",
+		"WARN: ~/category/package/Makefile:22: Variable \"UNDOCUMENTED\" is used but not defined.")
 }
 
 // https://gnats.netbsd.org/56352
@@ -321,7 +342,7 @@ func (s *Suite) Test_MkAssignChecker_checkLeftBsdPrefs__vartype_nil(c *check.C)
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: builtin.mk:2: VAR_SH is defined but not used.",
+		"WARN: builtin.mk:2: Variable \"VAR_SH\" is defined but not used.",
 		"WARN: builtin.mk:2: Include \"../../mk/bsd.prefs.mk\" before using \"?=\".")
 }
 
@@ -352,6 +373,9 @@ func (s *Suite) Test_MkAssignChecker_checkLeftUserSettable(c *check.C) {
 		"APPEND_DIRS=\tdefault",
 		"#COMMENTED_SAME?=\tdefault",
 		"#COMMENTED_DIFF?=\tdefault")
+	t.CreateFileLines("mk/infra.mk",
+		MkCvsID,
+		"ASSIGN_DIFF?=\tinfra")
 	t.Chdir("category/package")
 	t.FinishSetUp()
 
@@ -368,6 +392,11 @@ func (s *Suite) Test_MkAssignChecker_checkLeftUserSettable(c *check.C) {
 		"WARN: Makefile:26: Packages should not append to user-settable APPEND_DIRS.",
 		"WARN: Makefile:28: Package sets user-defined \"COMMENTED_DIFF\" to \"pkg\", "+
 			"which differs from the default value \"default\" from mk/defaults/mk.conf.")
+
+	// No warnings, as the pkgsrc infrastructure may override defaults.
+	G.Check("../../mk/infra.mk")
+
+	t.CheckOutputEmpty()
 }
 
 func (s *Suite) Test_MkAssignChecker_checkLeftUserSettable__before_prefs(c *check.C) {
@@ -437,7 +466,7 @@ func (s *Suite) Test_MkAssignChecker_checkLeftUserSettable__vartype_nil(c *check
 	//  comment. Therefore, it doesn't know that USER_SETTABLE is intended to be
 	//  used by other packages. There should be no warning.
 	t.CheckOutputLines(
-		"WARN: Makefile:20: USER_SETTABLE is defined but not used.")
+		"WARN: Makefile:20: Variable \"USER_SETTABLE\" is defined but not used.")
 }
 
 func (s *Suite) Test_MkAssignChecker_checkLeftPermissions__hacks_mk(c *check.C) {
@@ -491,7 +520,7 @@ func (s *Suite) Test_MkAssignChecker_checkLeftPermissions(c *check.C) {
 		"WARN: options.mk:3: The variable BUILD_DEFS should not be given a default value (only appended to) in this file.",
 		"WARN: options.mk:4: USE_TOOLS should not be used at load time in this file; "+
 			"it would be ok in Makefile.common or builtin.mk, but not buildlink3.mk or *.",
-		"WARN: options.mk:5: MY_TOOLS is used but not defined.",
+		"WARN: options.mk:5: Variable \"MY_TOOLS\" is used but not defined.",
 		"WARN: options.mk:10: "+
 			"The variable SET_ONLY should not be given a default value "+
 			"(only set) in this file.",
@@ -730,6 +759,34 @@ func (s *Suite) Test_MkAssignChecker_checkOp(c *check.C) {
 			"bsd.prefs.mk has to be included before.")
 }
 
+// The variable GMAKE_REQD is a single-value variable,
+// unlike most other REQD variables,
+// which are lists of version numbers, of which the highest one counts.
+//
+// See https://gnats.netbsd.org/59015.
+func (s *Suite) Test_MkAssignChecker_checkOp__GMAKE_REQD(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpPkgsrc()
+	t.SetUpPackage("category/package",
+		"# A single fixed version.",
+		"GMAKE_REQD=\t4.0",
+		"# Another version.",
+		"GMAKE_REQD+=\t4.0")
+	t.Chdir("category/package")
+	t.FinishSetUp()
+
+	G.Check(".")
+
+	t.CheckOutputLines(
+		"WARN: Makefile:23: "+
+			"The variable GMAKE_REQD should not be appended to "+
+			"(only set, or given a default value) in this file.",
+		"WARN: Makefile:23: "+
+			"The \"+=\" operator should only be used with lists, "+
+			"not with GMAKE_REQD.")
+}
+
 func (s *Suite) Test_MkAssignChecker_checkOpShell(c *check.C) {
 	t := s.Init(c)
 
@@ -810,17 +867,56 @@ func (s *Suite) Test_MkAssignChecker_checkOpAppendOnly(c *check.C) {
 	t := s.Init(c)
 
 	t.SetUpVartypes()
-	mklines := t.NewMkLines("filename.mk",
+	t.CreateFileLines("mk/bsd.prefs.mk")
+	t.Chdir("category/package")
+	mklines := t.SetUpFileMkLines("filename.mk",
 		MkCvsID,
 		"",
 		"CFLAGS=\t\t-O2",
-		"CFLAGS.SunOS=\t-O0")
+		"CFLAGS.SunOS=\t-O0",
+		"OBJCFLAGS=\t-O0",
+		"FFLAGS=\t\t-O0",
+		"RFLAGS=\t\t-O0",
+		"LFLAGS=\t\t-v",
+		"LDFLAGS=\t-lc",
+		"LINTFLAGS=\t-T",
+		"PFLAGS=\t\t-O0",
+		"YFLAGS=\t\t-Wall",
+		"LDADD=\t\t-lc",
+		"GCC_REQD=\t12.0",
+		"",
+		".include \"../../mk/bsd.prefs.mk\"",
+		"",
+		"CFLAGS.SunOS=\t-O1")
 
 	mklines.Check()
 
+	// TODO: The "defined but not used" warnings are wrong, as these
+	//  variables could be used by the pkgsrc infrastructure.
+	//  Or, if they really aren't passed to the *-build targets,
+	//  there's no point having these variables declared at the pkgsrc level.
 	t.CheckOutputLines(
-		"WARN: filename.mk:3: " +
-			"Assignments to \"CFLAGS\" should use \"+=\", not \"=\".")
+		"WARN: filename.mk:3: Assignments to \"CFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:5: Variable \"OBJCFLAGS\" is defined but not used.",
+		"WARN: filename.mk:5: Assignments to \"OBJCFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:6: Variable \"FFLAGS\" is defined but not used.",
+		"WARN: filename.mk:6: Assignments to \"FFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:7: Variable \"RFLAGS\" is defined but not used.",
+		"WARN: filename.mk:7: Assignments to \"RFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:8: Variable \"LFLAGS\" is defined but not used.",
+		"WARN: filename.mk:8: Assignments to \"LFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:9: Assignments to \"LDFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:10: Variable \"LINTFLAGS\" is defined but not used.",
+		"WARN: filename.mk:10: Assignments to \"LINTFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:11: Variable \"PFLAGS\" is defined but not used.",
+		"WARN: filename.mk:11: Assignments to \"PFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:12: Variable \"YFLAGS\" is defined but not used.",
+		"WARN: filename.mk:12: Assignments to \"YFLAGS\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:13: Variable \"LDADD\" is defined but not used.",
+		"WARN: filename.mk:13: Assignments to \"LDADD\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:14: Setting variable GCC_REQD should have a rationale.",
+		"WARN: filename.mk:14: Assignments to \"GCC_REQD\" should use \"+=\", not \"=\".",
+		"WARN: filename.mk:18: Assignments to \"CFLAGS.SunOS\" should use \"+=\", not \"=\".")
 }
 
 // After including bsd.prefs.mk, all assignments to GCC_REQD should use '+=',
@@ -1044,10 +1140,12 @@ func (s *Suite) Test_MkAssignChecker_checkRightConfigureArgs(c *check.C) {
 		"CONFIGURE_ARGS+=\t--host=host-platform",
 		"CONFIGURE_ARGS+=\t--infodir=info-dir",
 		"CONFIGURE_ARGS+=\t--mandir=man-dir",
-		"CONFIGURE_ARGS+=\t--quiet")
+		"CONFIGURE_ARGS+=\t--quiet",
+		"CONFIGURE_ARGS+=\t-q")
 	t.CreateFileLines("mk/configure/gnu-configure.mk",
 		MkCvsID,
 		"",
+		"HAS_CONFIGURE=\tyes",
 		"CONFIGURE_ARGS+=\t--prefix=${GNU_CONFIGURE_PREFIX:Q}",
 		"CONFIGURE_ARGS+=\t--libdir=${GNU_CONFIGURE_LIBDIR}",
 		".if 1",
@@ -1056,7 +1154,8 @@ func (s *Suite) Test_MkAssignChecker_checkRightConfigureArgs(c *check.C) {
 		"CONFIGURE_ARGS+=\t--build=${MACHINE_GNU_PLATFORM:Q}",
 		".endif",
 		"CONFIGURE_ARGS+=\t--enable-option-checking=yes",
-		"CONFIGURE_ARGS+=\t--quiet")
+		"CONFIGURE_ARGS+=\t--quiet",
+		"CONFIGURE_ARGS+=\t-q")
 	t.Chdir("category/package")
 	t.FinishSetUp()
 
@@ -1065,13 +1164,13 @@ func (s *Suite) Test_MkAssignChecker_checkRightConfigureArgs(c *check.C) {
 	t.CheckOutputLines(
 		"WARN: Makefile:21: "+
 			"The option \"--prefix\" is already handled "+
-			"by \"../../mk/configure/gnu-configure.mk\".",
+			"by ../../mk/configure/gnu-configure.mk:4.",
 		"WARN: Makefile:22: "+
 			"The option \"--build\" is already handled "+
-			"by \"../../mk/configure/gnu-configure.mk\".",
+			"by ../../mk/configure/gnu-configure.mk:7.",
 		"WARN: Makefile:26: "+
 			"The option \"--quiet\" is already handled "+
-			"by \"../../mk/configure/gnu-configure.mk\".")
+			"by ../../mk/configure/gnu-configure.mk:12.")
 }
 
 func (s *Suite) Test_MkAssignChecker_checkRightUseLanguages(c *check.C) {
@@ -1087,17 +1186,34 @@ func (s *Suite) Test_MkAssignChecker_checkRightUseLanguages(c *check.C) {
 	mklines := t.NewMkLines("filename.mk",
 		MkCvsID,
 		"",
-		"USE_LANGUAGES+=\tc c99 c++14 fortran")
+		"USE_LANGUAGES+=\tc c99 c++14 fortran ${OTHER}")
 
 	mklines.Check()
 
 	t.CheckOutputLines(
+		"WARN: filename.mk:3: Variable \"OTHER\" is used but not defined.",
 		"WARN: filename.mk:3: The feature \"c99\" should be added "+
 			"to USE_CC_FEATURES instead of USE_LANGUAGES.",
 		"WARN: filename.mk:3: The feature \"c++14\" should be added "+
 			"to USE_CXX_FEATURES instead of USE_LANGUAGES.")
 }
 
+func (s *Suite) Test_MkAssignChecker_checkRightUseLanguages__outside_pkgsrc(c *check.C) {
+	t := s.Init(c)
+	G.Project = NewNetBSDProject()
+	G.Pkgsrc = nil
+
+	mklines := t.NewMkLines("filename.mk",
+		MkCvsID,
+		"",
+		"USE_LANGUAGES+=\tc c99 c++14 fortran")
+
+	mklines.Check()
+
+	// No warning, as USE_LANGUAGES is a pkgsrc-specific variable.
+	t.CheckOutputEmpty()
+}
+
 func (s *Suite) Test_MkAssignChecker_checkMisc(c *check.C) {
 	t := s.Init(c)
 
@@ -1131,7 +1247,7 @@ func (s *Suite) Test_MkAssignChecker_checkMisc(c *check.C) {
 		"_TOOLS_VARNAME.sed=\tSED",
 		"WARN: filename.mk:2: Variable names starting with an underscore "+
 			"(_TOOLS_VARNAME.sed) are reserved for internal pkgsrc use.",
-		"WARN: filename.mk:2: _TOOLS_VARNAME.sed is defined but not used.")
+		"WARN: filename.mk:2: Variable \"_TOOLS_VARNAME.sed\" is defined but not used.")
 
 	test(
 		"DIST_SUBDIR=\t\t${PKGNAME}",
@@ -1145,7 +1261,7 @@ func (s *Suite) Test_MkAssignChecker_checkMisc(c *check.C) {
 
 	test(
 		"SITES_distfile.tar.gz=\t${MASTER_SITE_GITHUB:=user/}",
-		"WARN: filename.mk:2: SITES_distfile.tar.gz is defined but not used.",
+		"WARN: filename.mk:2: Variable \"SITES_distfile.tar.gz\" is defined but not used.",
 		"WARN: filename.mk:2: SITES_* is deprecated. Use SITES.* instead.")
 
 	test(
@@ -1316,7 +1432,7 @@ func (s *Suite) Test_MkAssignChecker_checkExprShell(c *check.C) {
 
 	t.CheckOutputLines(
 		"WARN: filename.mk:1: Unknown shell command \"grep\".",
-		"WARN: filename.mk:1: EXAMPLE_FILES is used but not defined.")
+		"WARN: filename.mk:1: Variable \"EXAMPLE_FILES\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkAssignChecker_mayBeDefined(c *check.C) {
@@ -1335,8 +1451,8 @@ func (s *Suite) Test_MkAssignChecker_mayBeDefined(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:3: _GOOD_PREFIX is defined but not used.",
+		"WARN: filename.mk:3: Variable \"_GOOD_PREFIX\" is defined but not used.",
 		"WARN: filename.mk:4: Variable names starting with an underscore (_BAD_PREFIX) are reserved for internal pkgsrc use.",
-		"WARN: filename.mk:4: _BAD_PREFIX is defined but not used.",
+		"WARN: filename.mk:4: Variable \"_BAD_PREFIX\" is defined but not used.",
 		"WARN: filename.mk:4: Variable _BAD_PREFIX is defined but not mentioned in the _VARGROUPS section.")
 }
