@@ -14,7 +14,7 @@ type MkCondChecker struct {
 }
 
 func NewMkCondChecker(mkLine *MkLine, mkLines *MkLines) *MkCondChecker {
-	return &MkCondChecker{MkLine: mkLine, MkLines: mkLines}
+	return &MkCondChecker{mkLine, mkLines}
 }
 
 func (ck *MkCondChecker) Check() {
@@ -127,10 +127,15 @@ func (ck *MkCondChecker) checkNotEmpty(not *MkCond) {
 	to := not.Empty.String()
 	fix.Notef("%s can be replaced with %s.", from, to)
 	fix.Explain(
-		"Besides being simpler to read, the expression will also fail",
-		"quickly with a \"Malformed conditional\" error from bmake",
+		"Besides being simpler to read, the expression will also",
+		"fail fast with a \"Variable XYZ is undefined\" or",
+		"(in bmake<=20250404)",
+		"a \"Malformed conditional\" error from bmake",
 		"if it should ever be undefined at this point.",
-		"This catches typos and other programming mistakes.")
+		"",
+		"Before querying a PKG_BUILD_OPTIONS variable,",
+		"that variable has to be defined by setting \"pkgbase\"",
+		"and then calling \"mk/pkg-build-options.mk\".")
 	fix.Replace(from, to)
 	fix.Apply()
 }
