@@ -417,6 +417,12 @@ func (s *Suite) Test_MkLexer_Expr(c *check.C) {
 
 	test("${_BUILD_DEFS.${v}:U${${v}}:${_BUILD_INFO_MOD.${v}}:Q}",
 		expr("_BUILD_DEFS.${v}", "U${${v}}", "${_BUILD_INFO_MOD.${v}}", "Q"))
+
+	test("${:!${UNAME} -s!:S/-//g:S/\\///g:C/^CYGWIN_.*$/Cygwin/}",
+		expr("", "!${UNAME} -s!", "S/-//g", "S/\\///g", "C/^CYGWIN_.*$/Cygwin/"))
+
+	test("${<:T}",
+		expr("<", "T"))
 }
 
 // Pkglint can replace $(VAR) with ${VAR}. It doesn't look at all components
@@ -488,6 +494,8 @@ func (s *Suite) Test_MkLexer_Varname(c *check.C) {
 	test("PKGPATH.category/package")
 
 	testRest("VARNAME/rest", "VARNAME", "/rest")
+
+	testRest("<:T", "<", ":T")
 }
 
 func (s *Suite) Test_MkLexer_exprText(c *check.C) {
@@ -579,7 +587,8 @@ func (s *Suite) Test_MkLexer_ExprModifiers(c *check.C) {
 	test("${VAR:!command!}", expr("VAR", "!command!"))
 
 	test("${VAR:!command}", expr("VAR"),
-		"WARN: Makefile:20: Invalid variable modifier \"!command\" for \"VAR\".")
+		"ERROR: Makefile:20: Modifier \"command}\" is missing the delimiter \"!\".",
+		"WARN: Makefile:20: Missing closing \"}\" for \"VAR\".")
 
 	test("${VAR:command!}", expr("VAR"),
 		"WARN: Makefile:20: Invalid variable modifier \"command!\" for \"VAR\".")
@@ -602,13 +611,19 @@ func (s *Suite) Test_MkLexer_ExprModifiers(c *check.C) {
 func (s *Suite) Test_MkLexer_exprModifier(c *check.C) {
 	t := s.Init(c)
 
-	p := NewMkLexer("${VAR:R:E:Ox:tA:tW:tw}", nil)
+	mkline := t.NewMkLine("filename.mk", 123, "")
 
-	expr := p.Expr()
+	test := func(expr string, wantModifiers ...MkExprModifier) {
+		p := NewMkLexer(expr, mkline)
+		e := p.Expr()
+		if t.CheckNotNil(e) {
+			t.CheckDeepEquals(e.modifiers, wantModifiers)
+		}
+	}
 
-	t.CheckDeepEquals(
-		expr.modifiers,
-		[]MkExprModifier{"R", "E", "Ox", "tA", "tW", "tw"})
+	test("${VAR:R:E:Ox:tA:tW:tw}", "R", "E", "Ox", "tA", "tW", "tw")
+
+	test("${VAR:!cmd!}", "!cmd!")
 }
 
 func (s *Suite) Test_MkLexer_exprModifier__S_parse_error(c *check.C) {
@@ -1049,6 +1064,9 @@ func (s *Suite) Test_MkLexer_exprModifierSubst(c *check.C) {
 	// Using the backslash as separator means that it cannot be used for anything
 	// else, not even for escaping other characters.
 	test("S\\.post1\\\\1}", false, ".post1", "", "1", "}")
+
+	// Using ' ' as a separator for the ':C' modifier is unusual but works.
+	test("C [0-5][0-9]$ 00 } -D${ts}", true, "[0-5][0-9]$", "00", "", "} -D${ts}")
 }
 
 func (s *Suite) Test_MkLexer_exprModifierAt__missing_at_after_variable_name(c *check.C) {
@@ -1125,6 +1143,47 @@ func (s *Suite) Test_MkLexer_exprModifierAt(c *check.C) {
 		"")
 }
 
+func (s *Suite) Test_MkLexer_parseModifierPart(c *check.C) {
+	t := s.Init(c)
+
+	mkline := t.NewMkLine("filename.mk", 123, "")
+
+	test := func(expr string, wantModifiers ...MkExprModifier) {
+		p := NewMkLexer(expr, mkline)
+		e := p.Expr()
+		if t.CheckNotNil(e) {
+			t.CheckDeepEquals(e.modifiers, wantModifiers)
+		}
+	}
+
+	test("${VAR:!cmd!}", "!cmd!")
+	t.CheckOutputEmpty()
+
+	test("${VAR:!cmd}", nil...)
+	t.CheckOutputLines(
+		"ERROR: filename.mk:123: Modifier \"cmd}\" is missing the delimiter \"!\".",
+		"WARN: filename.mk:123: Missing closing \"}\" for \"VAR\".")
+}
+
+func (s *Suite) Test_MkLexer_isEscapedModifierPart(c *check.C) {
+	t := s.Init(c)
+
+	mkline := t.NewMkLine("filename.mk", 123, "")
+
+	test := func(expr string, wantModifiers ...MkExprModifier) {
+		p := NewMkLexer(expr, mkline)
+		e := p.Expr()
+		if t.CheckNotNil(e) {
+			t.CheckDeepEquals(e.modifiers, wantModifiers)
+		}
+	}
+
+	test("${VAR:!cmd!}", "!cmd!")
+	t.CheckOutputEmpty()
+
+	test("${VAR:!cmd\\!!}", "!cmd\\!!")
+}
+
 func (s *Suite) Test_MkLexer_exprAlnum(c *check.C) {
 	t := s.Init(c)
 
