@@ -22,8 +22,8 @@ func (s *Suite) Test_MkLineChecker__unclosed_expr(c *check.C) {
 		"WARN: Makefile:2: Invalid part \"/dbus-1/system.d ${EGDIR/pam.d\" after variable name \"EGDIR\".",
 		"WARN: Makefile:2: Missing closing \"}\" for \"EGDIR/apparmor.d ${EGDIR/dbus-1/system.d ${EGDIR/pam.d\".",
 		"WARN: Makefile:2: Invalid part \"/apparmor.d ${EGDIR/dbus-1/system.d ${EGDIR/pam.d\" after variable name \"EGDIR\".",
-		"WARN: Makefile:2: EGDIRS is defined but not used.",
-		"WARN: Makefile:2: EGDIR/pam.d is used but not defined.")
+		"WARN: Makefile:2: Variable \"EGDIRS\" is defined but not used.",
+		"WARN: Makefile:2: Variable \"EGDIR/pam.d\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkLineChecker_Check__buildlink3_include_prefs(c *check.C) {
@@ -86,7 +86,7 @@ func (s *Suite) Test_MkLineChecker_Check__expr_modifier_L(c *check.C) {
 			"Invalid part \"/xkbcomp\" after variable name \"${XKBBASE}\".",
 		"WARN: x11/xkeyboard-config/Makefile:3: "+
 			"Invalid part \"/xkbcomp\" after variable name \"${XKBBASE}\".",
-		"WARN: x11/xkeyboard-config/Makefile:3: XKBBASE is used but not defined.")
+		"WARN: x11/xkeyboard-config/Makefile:3: Variable \"XKBBASE\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkLineChecker_checkEmptyContinuation(c *check.C) {
@@ -168,7 +168,7 @@ func (s *Suite) Test_MkLineChecker_checkText__WRKSRC(c *check.C) {
 		"\tprocess\":",
 		"\thttps://www.NetBSD.org/docs/pkgsrc/pkgsrc.html#build.builddirs",
 		"",
-		"WARN: ~/module.mk:3: WRKSRC is used but not defined.")
+		"WARN: ~/module.mk:3: Variable \"WRKSRC\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkLineChecker_checkTextWrksrcDotDot(c *check.C) {
@@ -323,8 +323,8 @@ func (s *Suite) Test_MkLineChecker_checkVartype__no_tracing(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:2: UNKNOWN is defined but not used.",
-		"WARN: filename.mk:3: CUR_DIR is defined but not used.")
+		"WARN: filename.mk:2: Variable \"UNKNOWN\" is defined but not used.",
+		"WARN: filename.mk:3: Variable \"CUR_DIR\" is defined but not used.")
 }
 
 func (s *Suite) Test_MkLineChecker_checkVartype__one_per_line(c *check.C) {
@@ -782,7 +782,7 @@ func (s *Suite) Test_MkLineChecker_checkDirectiveIndentation__multiline_indented
 	t.ExpectDiagnosticsAutofix(
 		doTest,
 		"NOTE: ~/options.mk:2: This directive should be indented by 0 spaces.",
-		"WARN: ~/options.mk:2--3: PLATFORM is used but not defined.",
+		"WARN: ~/options.mk:2--3: Variable \"PLATFORM\" is used but not defined.",
 		// If the indentation should ever change here, it is probably
 		// because MkLineParser.parseDirective has been changed to
 		// behave more like bmake, which preserves a bit more of the
@@ -827,7 +827,7 @@ func (s *Suite) Test_MkLineChecker_CheckRelativePath(c *check.C) {
 	t.CheckOutputLines(
 		"ERROR: ~/category/package/module.mk:2: A main pkgsrc package must not depend on a pkgsrc-wip package.",
 		"ERROR: ~/category/package/module.mk:3: A main pkgsrc package must not depend on a pkgsrc-wip package.",
-		"WARN: ~/category/package/module.mk:5: LATEST_PYTHON is used but not defined.",
+		"WARN: ~/category/package/module.mk:5: Variable \"LATEST_PYTHON\" is used but not defined.",
 		"WARN: ~/category/package/module.mk:11: References to other packages should "+
 			"look like \"../../category/package\", not \"../package\".",
 		"WARN: ~/category/package/module.mk:12: References to other packages should "+
@@ -1069,6 +1069,20 @@ func (s *Suite) Test_MkLineChecker_checkDirectiveEnd__unbalanced(c *check.C) {
 		"ERROR: filename.mk:4: Unmatched .endif.")
 }
 
+func (s *Suite) Test_MkLineChecker_checkDirectiveEnd__ifmake(c *check.C) {
+	t := s.Init(c)
+
+	mklines := t.NewMkLines("Makefile",
+		MkCvsID,
+		".ifmake first",
+		".elifmake second",
+		".endif")
+
+	mklines.Check()
+
+	t.CheckOutputEmpty()
+}
+
 func (s *Suite) Test_MkLineChecker_checkDirectiveFor(c *check.C) {
 	t := s.Init(c)
 
@@ -1082,6 +1096,13 @@ func (s *Suite) Test_MkLineChecker_checkDirectiveFor(c *check.C) {
 		".endfor",
 		"",
 		".for dir in ${PATH:M*/bin}",
+		".endfor",
+		"",
+		".for opt in $(PATH)", // Parentheses instead of braces.
+		".endfor",
+		"",
+		"DISTFILES=\t# none",
+		".for gem in ${DISTFILES:M*.gem:S/.gem$//g}",
 		".endfor")
 
 	mklines.Check()
@@ -1091,12 +1112,62 @@ func (s *Suite) Test_MkLineChecker_checkDirectiveFor(c *check.C) {
 		// converts the colon-separated list into a space-separated list,
 		// as required by the .for loop.
 
-		// This warning is correct since PATH is separated by colons, not by spaces.
+		// FIXME: Do not suggest the ':Q' modifier, instead suggest to use spaces.
 		"WARN: for.mk:5: Use ${PATH:Q} instead of ${PATH}.",
 
-		// This warning is also correct since the :M modifier doesn't
-		// turn a list into a non-list or vice versa.
-		"WARN: for.mk:8: Use ${PATH:M*/bin:Q} instead of ${PATH:M*/bin}.")
+		// Applying the ':M' modifier with a pattern to a single-value
+		// variable can be useful, as a form of pattern matching.
+		// More probably though, the intention was to see whether the PATH
+		// has _any_ directory ending in "/bin", instead of testing only
+		// the last directory.
+		// FIXME: Do not suggest the ':Q' modifier, instead suggest to use spaces.
+		"WARN: for.mk:8: Use ${PATH:M*/bin:Q} instead of ${PATH:M*/bin}.",
+
+		// TODO: Warn about round parentheses instead of curly braces.
+		// FIXME: Do not suggest the ':Q' modifier, instead suggest to use spaces.
+		"WARN: for.mk:11: Use ${PATH:Q} instead of ${PATH}.",
+
+		// TODO: Why not? The variable is guaranteed to be defined at this point.
+		"WARN: for.mk:15: DISTFILES should not be used at load time in any file.")
+}
+
+func (s *Suite) Test_MkLineChecker_checkDirectiveFor__continuation(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpVartypes()
+	mklines := t.NewMkLines("filename.mk",
+		MkCvsID,
+		"do-install:",
+		".for d in \\",
+		"    dir1 dir2 \\",
+		"    dir3 dir4 \\",
+		"    dir5 dir6 \\", // This line continuation is not intended
+		"\t: mkdir $d",
+		// This .for loop has an empty body.
+		".endfor")
+
+	mklines.Check()
+
+	// TODO: Warn about the unintended line continuation.
+	t.CheckOutputEmpty()
+}
+
+func (s *Suite) Test_MkLineChecker_checkDirectiveFor__items(c *check.C) {
+	t := s.Init(c)
+
+	t.SetUpVartypes()
+	mklines := t.NewMkLines("filename.mk",
+		MkCvsID,
+		".for f in $< $a $0",
+		".endfor")
+
+	mklines.Check()
+
+	// TODO: Warn about $a and $0 being ambiguous.
+	t.CheckOutputLines(
+		"WARN: filename.mk:2: Variable \"<\" is used but not defined.",
+		"WARN: filename.mk:2: Variable \"a\" is used but not defined.",
+		"WARN: filename.mk:2: Variable \"0\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkLineChecker_checkDirectiveFor__infrastructure(c *check.C) {
