@@ -60,7 +60,7 @@ type Package struct {
 	seenInclude bool
 
 	// The identifiers for which PKG_BUILD_OPTIONS is defined.
-	seenPkgbase Once
+	seenPkgbase map[string]struct{}
 
 	// During both load() and check(), tells whether bsd.prefs.mk has
 	// already been loaded directly or indirectly.
@@ -81,7 +81,8 @@ type Package struct {
 
 	IgnoreMissingPatches bool // In distinfo, don't warn about patches that cannot be found.
 
-	Once Once
+	warnedAboutConditionalInclusion OnceStringSlices
+	checkedPolicyUpdateLimited      OnceBool
 
 	// Contains the basenames of the distfiles that are mentioned in distinfo,
 	// for example "package-1.0.tar.gz", even if that file is in a DIST_SUBDIR.
@@ -110,6 +111,7 @@ func NewPackage(dir CurrPath) *Package {
 		bl3:                   make(map[PackagePath]*MkLine),
 		bl3Data:               make(map[Buildlink3ID]*Buildlink3Data),
 		included:              NewIncludedMap(),
+		seenPkgbase:           make(map[string]struct{}),
 		conditionalIncludes:   make(map[PackagePath]*MkLine),
 		unconditionalIncludes: make(map[PackagePath]*MkLine),
 	}
@@ -198,7 +200,7 @@ func (pkg *Package) loadBuildlink3Pkgbase(filename CurrPath, fragmentMklines *Mk
 	}
 	fragmentMklines.ForEach(func(mkline *MkLine) {
 		if mkline.IsVarassign() && mkline.Varname() == "pkgbase" {
-			pkg.seenPkgbase.FirstTime(mkline.Value())
+			pkg.seenPkgbase[mkline.Value()] = struct{}{}
 		}
 	})
 }
@@ -353,7 +355,7 @@ func (pkg *Package) parseLine(mklines *MkLines, mkline *MkLine, allLines *MkLine
 		}
 
 		if varname == "pkgbase" {
-			pkg.seenPkgbase.FirstTime(mkline.Value())
+			pkg.seenPkgbase[mkline.Value()] = struct{}{}
 		}
 	}
 	return true
@@ -552,7 +554,10 @@ func (pkg *Package) loadPlistDirs(plistFilename CurrPath) {
 		make(map[RelPath]*PlistLine),
 		make(map[RelPath]*PlistLine),
 		"",
-		Once{},
+		OnceBool{},
+		OnceBool{},
+		OnceBool{},
+		OnceStrings{},
 		false}
 	plistLines := ck.Load(lines)
 
@@ -612,6 +617,7 @@ func (pkg *Package) check(filenames []CurrPath, mklines, allLines *MkLines) {
 			haveDistinfo = true
 		}
 		pkg.checkOwnerMaintainer(filename)
+		pkg.checkPolicyUpdateLimited()
 		pkg.checkFreeze(filename)
 	}
 
@@ -1051,7 +1057,7 @@ func (pkg *Package) checkGnuConfigureUseLanguages() {
 // USE_LANGUAGES, as these would be ignored by the pkgsrc infrastructure.
 func (pkg *Package) checkUseLanguagesCompilerMk(mklines *MkLines) {
 
-	var seen Once
+	var seen OnceStrings
 
 	handleVarassign := func(mkline *MkLine) {
 		if mkline.Varname() != "USE_LANGUAGES" {
@@ -1481,6 +1487,30 @@ func (pkg *Package) checkOwnerMaintainer(filename CurrPath) {
 		"keyword \"maintainer\", for more information.")
 }
 
+func (pkg *Package) checkPolicyUpdateLimited() {
+	if !pkg.checkedPolicyUpdateLimited.FirstTime() {
+		return
+	}
+
+	varname := "POLICY_UPDATE_LIMITED"
+	limits := pkg.vars.LastValue(varname)
+	if limits == "" {
+		return
+	}
+	mkline := pkg.vars.LastDefinition(varname)
+	if containsExpr(limits) {
+		mkline.Errorf("The value for \"%s\" must be given directly.", varname)
+		return
+	}
+
+	if isLocallyModified(mkline.Filename()) {
+		line := NewLineWhole(pkg.File("."))
+		line.Warnf("Changes to this package require extensive testing.")
+		line.Explain(
+			seeGuide("pkgsrc Policies", "policies"))
+	}
+}
+
 func (pkg *Package) checkFreeze(filename CurrPath) {
 	freezeStart := G.Pkgsrc.changes.LastFreezeStart
 	if freezeStart == "" || G.Pkgsrc.changes.LastFreezeEnd != "" {
@@ -1585,7 +1615,7 @@ func (pkg *Package) checkIncludeConditionally(mkline *MkLine, indentation *Inden
 
 	if indentation.IsConditional() {
 		if other := pkg.unconditionalIncludes[key]; other != nil {
-			if !pkg.Once.FirstTimeSlice("checkIncludeConditionally", mkline.String(), other.String()) {
+			if !pkg.warnedAboutConditionalInclusion.FirstTimeSlice(mkline.String(), other.String()) {
 				return
 			}
 
@@ -1601,7 +1631,7 @@ func (pkg *Package) checkIncludeConditionally(mkline *MkLine, indentation *Inden
 
 	} else {
 		if other := pkg.conditionalIncludes[key]; other != nil {
-			if !pkg.Once.FirstTimeSlice("checkIncludeConditionally", other.String(), mkline.String()) {
+			if !pkg.warnedAboutConditionalInclusion.FirstTimeSlice(other.String(), mkline.String()) {
 				return
 			}
 
@@ -1736,7 +1766,7 @@ func NewPlistContent() PlistContent {
 
 // IncludedMap remembers which files the package Makefile has included,
 // including indirect files.
-// See Once.
+// See OnceStrings.
 type IncludedMap struct {
 	m     map[PackagePath]struct{}
 	Trace bool
