@@ -1533,7 +1533,17 @@ func (s *Suite) Test_plistLineSorter_Sort(c *check.C) {
 		"${PLIST.linux}${PLIST.x86_64}lib/lib-linux-x86_64.so", // Double condition, see graphics/graphviz
 		"lib/after.la",
 		"@exec echo \"after lib/after.la\"")
-	ck := PlistChecker{nil, nil, nil, "", Once{}, false}
+	ck := PlistChecker{
+		nil,
+		nil,
+		nil,
+		"",
+		OnceBool{},
+		OnceBool{},
+		OnceBool{},
+		OnceStrings{},
+		false,
+	}
 	plines := ck.newLines(lines)
 
 	sorter1 := newPlistLineSorter(plines)
@@ -1541,7 +1551,17 @@ func (s *Suite) Test_plistLineSorter_Sort(c *check.C) {
 
 	cleanedLines := append(append(lines.Lines[0:5], lines.Lines[6:8]...), lines.Lines[9:]...) // Remove ${UNKNOWN} and @exec
 
-	sorter2 := newPlistLineSorter((&PlistChecker{nil, nil, nil, "", Once{}, false}).
+	sorter2 := newPlistLineSorter((&PlistChecker{
+		nil,
+		nil,
+		nil,
+		"",
+		OnceBool{},
+		OnceBool{},
+		OnceBool{},
+		OnceStrings{},
+		false,
+	}).
 		newLines(NewLines(lines.Filename, cleanedLines)))
 
 	t.CheckNil(sorter2.unsortable)
